@@ -6,7 +6,7 @@ Main application window
 """
 
 from __future__ import unicode_literals
-from gi.repository import Gtk, Gio, Gdk, GLib
+from gi.repository import Gtk, Gio, Gdk, GLib, GdkPixbuf
 from syncthing_gtk.tools import _
 from syncthing_gtk.tools import (
 	IS_UNITY, IS_GNOME, IS_I3, IS_MATE, IS_XFCE, IS_WINDOWS, IS_XP,
@@ -22,22 +22,25 @@ from syncthing_gtk.foldereditor import FolderEditorDialog
 from syncthing_gtk.tools import parse_config_arguments
 from syncthing_gtk.configuration import Configuration
 from syncthing_gtk.daemonprocess import DaemonProcess
-from syncthing_gtk.stdownloader import StDownloader
 from syncthing_gtk.timermanager import TimerManager
 from syncthing_gtk.uibuilder import UIBuilder
 from syncthing_gtk.identicon import IdentIcon
 from syncthing_gtk.infobox import InfoBox
-from syncthing_gtk.watcher import Watcher
 from syncthing_gtk.ribar import RIBar
+try:
+	from syncthing_gtk.stdownloader import StDownloader
+except ImportError:
+	StDownloader = None
+
 
 from datetime import datetime
 import os, webbrowser, sys, time, logging, shutil, re
 log = logging.getLogger("App")
 
 # Internal version used by updater (if enabled)
-INTERNAL_VERSION		= "v0.9.3.1"
+INTERNAL_VERSION		= "v0.9.4"
 # Minimal Syncthing version supported by App
-MIN_ST_VERSION			= "0.14.40"
+MIN_ST_VERSION			= "0.14.48"
 
 COLOR_DEVICE			= "#707070"					# Dark-gray
 COLOR_DEVICE_SYNCING	= "#2A89C8"					# Blue
@@ -111,7 +114,6 @@ class App(Gtk.Application, TimerManager):
 			not IS_UNITY and (not self.config["use_old_header"] or IS_GNOME)
 			and (Gtk.get_major_version(), Gtk.get_minor_version()) >= (3, 10) )
 		
-		self.watcher = None
 		self.daemon = None	# Created by setup_connection method
 		# If enabled (by -o argument), daemon output is captured and printed
 		# to stdout
@@ -285,7 +287,6 @@ class App(Gtk.Application, TimerManager):
 			return action
 		add_simple_action('webui', self.cb_menu_webui)
 		add_simple_action('daemon_output', self.cb_menu_daemon_output).set_enabled(False)
-		add_simple_action('inotify_output', self.cb_menu_inotify_output).set_enabled(False)
 		add_simple_action('preferences', self.cb_menu_ui_settings)
 		add_simple_action('about', self.cb_about)
 		add_simple_action('quit', self.cb_exit)
@@ -338,8 +339,11 @@ class App(Gtk.Application, TimerManager):
 					self["edit-menu-icon"].set_from_icon_name("emblem-system-symbolic", self["edit-menu-icon"].get_icon_name()[1])
 		
 		# Set window title in way that even Gnome can understand
+		icon = os.path.join(self.iconpath, "syncthing-gtk.png")
 		self["window"].set_title(_("Syncthing-GTK"))
 		self["window"].set_wmclass("Syncthing GTK", "Syncthing GTK")
+		if os.path.exists(icon):
+			self["window"].set_icon(GdkPixbuf.Pixbuf.new_from_file(icon))
 		self.add_window(self["window"])
 	
 	def setup_statusicon(self):
@@ -374,10 +378,6 @@ class App(Gtk.Application, TimerManager):
 			# This is pretty-much fatal. Display error message and bail out.
 			self.cb_syncthing_con_error(self.daemon, Daemon.UNKNOWN, str(e), e)
 			return False
-		# Enable filesystem watching and desktop notifications,
-		# if desired and possible
-		if not Watcher is None:
-			self.watcher = Watcher(self, self.daemon)
 		if HAS_DESKTOP_NOTIFY:
 			if self.config["notification_for_update"] or self.config["notification_for_error"]:
 				self.notifications = Notifications(self, self.daemon)
@@ -525,9 +525,19 @@ class App(Gtk.Application, TimerManager):
 			return
 		
 		# Define callbacks
-		def cb_cu_error(*a):
+		# Define callbacks
+		def cb_cu_error(sd, e, message):
 			# Version check failed. Try it again later
-			self.timer("updatecheck", 1 * 60 * 60, self.check_for_upgrade)
+			if "WinHttp" in str(e) and "SECURE_FAILURE" in str(e) and self["infobar"] == None:
+				message = _("Your Windows version doesn't supports cryptographic standards needed\n"
+					"for Syncthing-GTK to check for Syncthing updates.\n"
+					"Please, install <a href='%(url)s'>this Windows update</a> or disable update feature."
+				) % { 'url': "https://support.microsoft.com/en-us/help/3140245/" }
+				r = RIBar(message, Gtk.MessageType.WARNING)
+				self["infobar"] = r
+				self.show_info_box(r)
+			else:
+				self.timer("updatecheck", 1 * 60 * 60, self.check_for_upgrade)
 		
 		def cb_cu_progress(sd, progress, pb):
 			pb.set_fraction(progress)
@@ -800,9 +810,13 @@ class App(Gtk.Application, TimerManager):
 		if config["options"]["urAccepted"] == 0:
 			# User did not responded to usage reporting yet. Ask
 			self.ask_for_ur()
-		
-		if not self.watcher is None:
-			self.watcher.start()
+
+		if "use_inotify" in self.config:
+			from syncthing_gtk.configuration import migrate_fs_watch
+			if migrate_fs_watch(self.config, config):
+				self.daemon.write_config(config, lambda *a: False)
+				self.config.save()
+				log.info("Filesystem watcher configuration migrated")
 	
 	def cb_syncthing_error(self, daemon, message):
 		""" Handles errors reported by syncthing daemon """
@@ -1024,21 +1038,17 @@ class App(Gtk.Application, TimerManager):
 				device.set_status(_("Up to Date"))
 	
 	def cb_syncthing_folder_added(self, daemon, rid, r):
-		box = self.show_folder(
+		self.show_folder(
 			rid, r["label"], r["path"],
-			r["type"] == "readonly",
+			r["type"] in ["readonly", "sendonly"],
 			r["ignorePerms"], 
 			r["rescanIntervalS"],
+			r["fsWatcherEnabled"],
 			sorted(
 				[ self.devices[n["deviceID"]] for n in r["devices"] if n["deviceID"] in self.devices ],
 				key=lambda x : x.get_title().lower()
 				)
 			)
-		if not self.watcher is None:
-			if rid in self.config["use_inotify"]:
-				self.watcher.watch(box["id"], box["norm_path"])
-				if IS_WINDOWS:
-					self.lookup_action('inotify_output').set_enabled(True)
 	
 	def cb_syncthing_folder_data_changed(self, daemon, rid, data):
 		if rid in self.folders:	# Should be always
@@ -1359,7 +1369,7 @@ class App(Gtk.Application, TimerManager):
 					self["window"].move(x, y)
 				GLib.idle_add(move_back)
 	
-	def show_folder(self, id, label, path, is_master, ignore_perms, rescan_interval, shared):
+	def show_folder(self, id, label, path, is_master, ignore_perms, rescan_interval, fswatcher_enabled, shared):
 		""" Shared is expected to be list """
 		display_path = path
 		if IS_WINDOWS:
@@ -1414,7 +1424,7 @@ class App(Gtk.Application, TimerManager):
 		box.set_value("master",	_("Send Only") if is_master else _("Send & Receive"))
 		box.set_value("ignore",	_("Yes") if ignore_perms else _("No"))
 		box.set_value("rescan",	"%s s%s" % (
-			rescan_interval, " " + _("(watch)") if id in self.config["use_inotify"] else "" ))
+			rescan_interval, " " + _("(watch)") if fswatcher_enabled else "" ))
 		box.set_value("shared",	", ".join([ n.get_title() for n in shared ]))
 		box.set_value("b_master", is_master)
 		box.set_value("can_override", False)
@@ -1499,8 +1509,6 @@ class App(Gtk.Application, TimerManager):
 		self.error_boxes = []
 		self.error_messages = set([])
 		self.cancel_all() # timers
-		if not self.watcher is None:
-			self.watcher.kill()
 		self.daemon.reconnect()
 	
 	def refresh(self):
@@ -1511,13 +1519,7 @@ class App(Gtk.Application, TimerManager):
 		Looks cleaner & prevents UI from blinking.
 		"""
 		log.debug("Reloading config...")
-		if not self.watcher is None:
-			self.watcher.kill()
-			self.lookup_action('inotify_output').set_enabled(False)
-		def callback(*a):
-			if not self.watcher is None:
-				GLib.timeout_add_seconds(1, self.watcher.start)
-		self.daemon.reload_config(callback)
+		self.daemon.reload_config()
 	
 	def change_setting_async(self, setting_name, value, retry_on_error=False, restart=True):
 		"""
@@ -1601,8 +1603,6 @@ class App(Gtk.Application, TimerManager):
 				# Always kill subprocess on windows
 				self.process.kill()
 				self.process = None
-				if not self.watcher is None:
-					self.watcher.kill()
 			elif self.config["autokill_daemon"] == 2:	# Ask
 				d = Gtk.MessageDialog(
 					self["window"],
@@ -1953,22 +1953,6 @@ class App(Gtk.Application, TimerManager):
 			d = DaemonOutputDialog(self, self.process)
 			d.show(None)
 	
-	def cb_menu_inotify_output(self, *a):
-		# Available & called only on Windows
-		if hasattr(self.watcher, "proc") and not self.watcher.proc is None:
-			d = DaemonOutputDialog(self, self.watcher.proc)
-			d.show(None, _("Syncthing-Inotify Output"))
-		else:
-			d = Gtk.MessageDialog(
-					self["window"],
-					Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-					Gtk.MessageType.ERROR, Gtk.ButtonsType.CLOSE,
-					_("Syncthing-Inotify is unavailable or failed to start")
-				)
-			d.run()
-			d.hide()
-			d.destroy()
-	
 	def cb_statusicon_click(self, *a):
 		""" Called when user clicks on status icon """
 		# Hide / show main window
@@ -2077,6 +2061,9 @@ class App(Gtk.Application, TimerManager):
 			wizard.hide()
 			wizard.destroy()
 			self.show()
+			if self.process:
+				self.process.kill()
+				self.cb_daemon_exit(self.process, 0)
 			if self.setup_connection():
 				self.daemon.reconnect()
 		else:
@@ -2110,27 +2097,40 @@ class App(Gtk.Application, TimerManager):
 		Check if daemon binary exists.
 		If not, ask user where did he put it
 		"""
-		from syncthing_gtk.finddaemondialog import FindDaemonDialog
 		# Prepare FindDaemonDialog instance where user can
 		# set new path for syncthing_binary
-		d = FindDaemonDialog(self)
-		d.load()
-		d.set_transient_for(self["window"] if self.connect_dialog is None
-				else self.connect_dialog)
-		# If binary exists, assume that something is completly wrong,
-		# and change error message
-		if os.path.exists(self.config["syncthing_binary"]):
-			d.set_message("%s\n%s %s\n\n%s" % (
-					_("Failed to start Syncthing daemon."),
-					_("Error message:"), str(exception),
-					_("Please, check your installation or set new path to Syncthing daemon binary."),
-			))
-			d.hide_download_button()
-		# Let dialog run and try running syncthing again if new
-		# syncthing_binary is acquired
-		r = d.run()
-		d.destroy()
-		if r == FindDaemonDialog.RESPONSE_SAVED:
-			self.cb_daemon_exit(self.process, -1)
+		try:
+			from syncthing_gtk.finddaemondialog import FindDaemonDialog
+			d = FindDaemonDialog(self)
+		except ImportError:
+			d = None
+		
+		if d is None:
+			# FindDaemonDialog can be disabled by setup.py; If that's the case,
+			# setting is reset to default and 1st run wizard is started
+			self.config["syncthing_binary"] = self.config.get_default_value("syncthing_binary")
+			self.config.save()
+			self.hide()
+			self.show_wizard()
+			self.wizard.only_page(1)
 		else:
-			self.quit()
+			d.load()
+			d.set_transient_for(self["window"] if self.connect_dialog is None
+					else self.connect_dialog)
+			# If binary exists, assume that something is completly wrong,
+			# and change error message
+			if os.path.exists(self.config["syncthing_binary"]):
+				d.set_message("%s\n%s %s\n\n%s" % (
+						_("Failed to start Syncthing daemon."),
+						_("Error message:"), str(exception),
+						_("Please, check your installation or set new path to Syncthing daemon binary."),
+				))
+				d.hide_download_button()
+			# Let dialog run and try running syncthing again if new
+			# syncthing_binary is acquired
+			r = d.run()
+			d.destroy()
+			if r == FindDaemonDialog.RESPONSE_SAVED:
+				self.cb_daemon_exit(self.process, -1)
+			else:
+				self.quit()
