@@ -10,7 +10,6 @@ from gi.repository import Gtk
 from syncthing_gtk.tools import _ # gettext function
 from syncthing_gtk.tools import generate_folder_id
 from syncthing_gtk.editordialog import EditorDialog, strip_v
-from syncthing_gtk.watcher import Watcher
 import os, re, logging
 log = logging.getLogger("FolderEditor")
 
@@ -19,7 +18,7 @@ COLOR_NEW				= "#A0A0A0"
 RE_GEN_ID = re.compile("([a-zA-Z0-9\-\._]{1,64}).*")
 VALUES = [ "vlabel", "vid", "vpath", "vreadOnly", "vignorePerms", "vdevices",
 	"vversioning", "vkeepVersions", "vrescanIntervalS", "vmaxAge",
-	"vversionsPath", "vinotify", "vcleanoutDays", "vcommand", "vorder",
+	"vversionsPath", "vfsWatcherEnabled", "vcleanoutDays", "vcommand", "vorder",
 	"vminDiskFreePct"
 	]
 VERSIONING_TYPES = set(['simple', 'staggered', 'trashcan', 'external'])
@@ -80,11 +79,9 @@ class FolderEditorDialog(EditorDialog):
 		elif key == "versionsPath":
 			return self.get_burried_value("versioning/params/versionsPath", self.values, "")
 		elif key == "readOnly":
-			return self.get_burried_value("type", self.values, "") == "readonly"
+			return self.get_burried_value("type", self.values, "") in ("readonly", "sendonly")
 		elif key == "versioning":
 			return self.get_burried_value("versioning/type", self.values, "")
-		elif key == "inotify":
-			return self.id in self.app.config["use_inotify"]
 		else:
 			return EditorDialog.get_value(self, key)
 	
@@ -115,20 +112,7 @@ class FolderEditorDialog(EditorDialog):
 			self.create_dicts(self.values, ("versioning", "params", "versionsPath"))
 			self.values["versioning"]["params"]["versionsPath"] = value
 		elif key == "readOnly":
-			self.values["type"] = "readonly" if value else "readwrite"
-		elif key == "inotify":
-			id = self.id
-			if id is None:
-				# Happens when saving new folder
-				id = self["vid"].get_text().strip()
-			l = self.app.config["use_inotify"]
-			if value:
-				if not id in l:
-					l.append(id)
-			else:
-				while id in l:
-					l.remove(id)
-			self.app.config["use_inotify"] = l
+			self.values["type"] = "sendonly" if value else "sendreceive"
 		else:
 			EditorDialog.set_value(self, key, value)
 	
@@ -175,11 +159,6 @@ class FolderEditorDialog(EditorDialog):
 			log.exception(e)
 			self.close()
 			return False
-		if Watcher is None:
-			self["vinotify"].set_sensitive(False)
-			self["lblinotify"].set_sensitive(False)
-			self["vinotify"].set_tooltip_text(_("Please, install pyinotify package to use this feature"))
-			self["lblinotify"].set_tooltip_text(_("Please, install pyinotify package to use this feature"))
 		return self.display_values(VALUES)
 	
 	#@Overrides
@@ -241,7 +220,7 @@ class FolderEditorDialog(EditorDialog):
 			box = self.app.show_folder(
 				self.get_value("id"), self.get_value("label"), self.get_value("path"),
 				self.get_value("readOnly"), self.get_value("ignorePerms"),
-				self.get_value("rescanIntervalS"),
+				self.get_value("rescanIntervalS"), self.get_value("fsWatcherEnabled"),
 				sorted(
 					[ self.app.devices[n["deviceID"]] for n in self.get_value("devices") ],
 					key=lambda x : x.get_title().lower()
@@ -277,6 +256,22 @@ class FolderEditorDialog(EditorDialog):
 		self.update_special_widgets()
 		self["vid"].set_sensitive(not readonly)
 	
+	def on_vfsWatcherEnabled_toggled(self, cb, *a):
+		# Called when checkbox value changes to automatically change rescan interval
+		if self._loading: return
+		vrescanIntervalS = self.builder.get_object("vrescanIntervalS")
+		interval = vrescanIntervalS.get_value()
+		if cb.get_active():
+			# fswatch enabled, increase rescan interval
+			if interval < 720:
+				vrescanIntervalS.set_value(interval * 60)
+		else:
+			# fswatch disabled, return rescan interval back
+			if interval > 300:
+				vrescanIntervalS.set_value(interval / 60)
+				
+		# print self.get_value("vfsWatcherEnabled"),  cb.get_value()
+	
 	def mark_device(self, nid):
 		""" Marks (checks) checkbox for specified device """
 		if "vdevices" in self:	# ... only if there are checkboxes here
