@@ -12,9 +12,12 @@ from syncthing_gtk.tools import (
 )
 from syncthing_gtk.notifications import Notifications, HAS_DESKTOP_NOTIFY
 from syncthing_gtk.editordialog import EditorDialog
-from syncthing_gtk.stdownloader import StDownloader
 from syncthing_gtk.tools import _ # gettext function
 from syncthing_gtk.configuration import LONG_AGO
+try:
+	from syncthing_gtk.stdownloader import StDownloader
+except ImportError:
+	StDownloader = None
 import os, logging
 
 log = logging.getLogger("UISettingsDialog")
@@ -83,6 +86,9 @@ class UISettingsDialog(EditorDialog):
 			self["vuse_old_header"].set_no_show_all(True)
 			self["vicons_in_menu"].set_visible(False)
 			self["vicons_in_menu"].set_no_show_all(True)
+		if IS_GNOME:
+			self["vautostart"].set_visible(False)
+			self["vautostart"].set_no_show_all(True)
 		if not HAS_DESKTOP_NOTIFY:
 			# Disable notifications settings if required
 			# library is not available
@@ -119,8 +125,9 @@ class UISettingsDialog(EditorDialog):
 				log.warning("Cannot find %s.py required to support %s", plugin, name)
 		self["fmLblIntegrationStatus"].set_text("\n".join(status))
 		if StDownloader is None:
-			self["vst_autoupdate"].set_visible(False)
-			self["lblAutoupdate"].set_visible(False)
+			for name in ("vst_autoupdate", "lblAutoupdate", "lblsyncthing_binary",
+						 "lblsyncthing_binary2", "vsyncthing_binary", "btBrowse"):
+				self[name].set_visible(False)
 		self.cb_data_loaded(copy)
 		self.cb_check_value()
 	
